# proper-new

A script to generate a new Proper project

Usage: `uvx proper_new <path> [options]`

| Option            | Description |
|-------------------|-------------|
| **--name**        | Optional name of the app instead of the one in `path`
| **--src**         | Optional source url/path of the blueprint instead of the default one
| **--force**       | Overwrite files that already exist, without asking. `False` by default
| **--no-tailwind** | Do not use Tailwind CSS.
